[−][src]Enum pleco::core::GenTypes
Types of move generating options.
GenTypes::All -> All available moves.
GenTypes::Captures -> All captures and both capture/non-capture promotions.
GenTypes::Quiets -> All non captures and both capture/non-capture promotions.
GenTypes::QuietChecks -> Moves likely to give check.
GenTypes::Evasions -> Generates evasions for a board in check.
GenTypes::NonEvasions -> Generates all moves for a board not in check.
Safety
GenTypes::QuietChecks and GenTypes::NonEvasions can only be used if the board
if not in check, while GenTypes::Evasions can only be used if the the board is
in check. The remaining GenTypes can be used legally whenever.
Variants
AllCapturesQuietsQuietChecksEvasionsNonEvasionsTrait Implementations
impl Copy for GenTypes[src]
impl PartialEq<GenTypes> for GenTypes[src]
fn eq(&self, other: &GenTypes) -> bool[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
impl Clone for GenTypes[src]
fn clone(&self) -> GenTypes[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
Performs copy-assignment from source. Read more
impl Debug for GenTypes[src]