[−][src]Function pleco::tools::prefetch_write
pub fn prefetch_write<T>(ptr: *const T)
Prefetch's ptr to all levels of the cache.
For some platforms this may compile down to nothing, and be optimized away.
To prevent compiling down into nothing, compilation must be done for a
x86 or x86_64 platform with SSE instructions available. An easy way to
do this is to add the environmental variable RUSTFLAGS=-C target-cpu=native.